import React from "react";
import { cn } from "@/lib/utils";
import {
  Tooltip,
  TooltipContent,
  TooltipProvider,
  TooltipTrigger,
  TooltipArrow,
} from "@/components/ui/tooltip";
import Link from "next/link";
import { Image } from "react-bootstrap";
import { useSidebar } from "@/store";

import { useMediaQuery } from "@/hooks/use-media-query";
const SingleIconMenu = ({ index, activeIndex, item, locationName }) => {
  const { icon, title, href } = item;
  const { showText } = useSidebar();
  const isDesktop = useMediaQuery("(min-width: 1280px)");
  return (
    <>
      <div className="flex transition-all duration-300">
        <TooltipProvider>
          <Tooltip>
            <TooltipTrigger asChild>
              {href ? (
                <Link
                  prefetch={true}
                  href={href}
                  className={cn(
                    "h-12 w-12 mx-5 rounded-md  transition-all duration-300 flex flex-col items-center justify-center cursor-pointer relative",
                    {
                      "bg-primary/10  text-primary": locationName === href,
                      "text-default-500 dark:text-default-400 hover:bg-primary/10  hover:text-primary ":
                        locationName !== href,
                    }
                  )}
                >
                  <item.icon className="w-6 h-6" />
                </Link>
              ) : (
                <button
                  className={cn(
                    "h-12 w-12 mx-5 rounded-md transition-all duration-300 flex flex-col items-center justify-center cursor-pointer relative  ",
                    {
                      "bg-primary/10 dark:bg-primary dark:text-primary-foreground  text-primary data-[state=delayed-open]:bg-primary/10 ":
                        activeIndex === index,
                      " text-default-500 dark:text-default-400 data-[state=delayed-open]:bg-primary/10  data-[state=delayed-open]:text-primary":
                        activeIndex !== index,
                    }
                  )}
                >
                  <item.icon className="w-6 h-6" />
                </button>
              )}
            </TooltipTrigger>
            <TooltipContent side="right">{item.title}</TooltipContent>

          </Tooltip>
        </TooltipProvider>
        {
          !showText &&
          <div style={{ marginTop: "13px" }} className="transition-all duration-300">
            {href ? (
              <Link href={href}> <p style={{ fontSize: "17px", marginLeft: "-10px", fontWeight: "bolder" }}>{item.title}</p></Link>
            ) : (
              <Link href="#"> <p style={{ fontSize: "17px", marginLeft: "-10px", fontWeight: "bolder" }}>{item.title}</p></Link>

            )}
          </div>
        }
        {!isDesktop && <div style={{ marginTop: "13px" }}>
          {href ? (
            <Link href={href}> <p style={{ fontSize: "17px", marginLeft: "-10px", fontWeight: "bolder" }}>{item.title}</p></Link>
          ) : (
            <Link href="#"> <p style={{ fontSize: "17px", marginLeft: "-10px", fontWeight: "bolder" }}>{item.title}</p></Link>

          )}
        </div>}
      </div>
    </>
  );
};

export default SingleIconMenu;
